pub struct CliOutput {
pub stdout: String,
pub stderr: String,
pub exit_code: i32,
}Fields
stdout: Stringstderr: Stringexit_code: i32Trait Implementations
Sourceimpl JsonSchema for CliOutput
impl JsonSchema for CliOutput
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CliOutput
impl RefUnwindSafe for CliOutput
impl Send for CliOutput
impl Sync for CliOutput
impl Unpin for CliOutput
impl UnwindSafe for CliOutput