pub struct HttpOutput {
pub status: u16,
pub body: Value,
pub headers: FxHashMap<String, String>,
}Fields
status: u16body: Valueheaders: FxHashMap<String, String>Trait Implementations
Sourceimpl Debug for HttpOutput
impl Debug for HttpOutput
Sourceimpl JsonSchema for HttpOutput
impl JsonSchema for HttpOutput
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HttpOutput
impl RefUnwindSafe for HttpOutput
impl Send for HttpOutput
impl Sync for HttpOutput
impl Unpin for HttpOutput
impl UnwindSafe for HttpOutput